securitysettings/eapqtdialogs/inc/eapfastcreatemasterkeyquerydialog.h
changeset 42 53085837e73a
parent 39 fe6b6762fccd
--- a/securitysettings/eapqtdialogs/inc/eapfastcreatemasterkeyquerydialog.h	Tue Jul 06 14:18:35 2010 +0300
+++ b/securitysettings/eapqtdialogs/inc/eapfastcreatemasterkeyquerydialog.h	Wed Aug 18 09:50:56 2010 +0300
@@ -11,25 +11,39 @@
 *
 * Contributors:
 *
 * Description: Fast Create Master Key Query Dialog
 *
 */
 
 /*
-* %version: 3 %
+* %version: 4 %
 */
 
 #ifndef __EAPFASTCREATEMASTERKEYQUERYDIALOG_H__
 #define __EAPFASTCREATEMASTERKEYQUERYDIALOG_H__
 
-
+// System includes
 #include <HbInputDialog>
 #include <hbdevicedialoginterface.h>
 
+// User includes
+
+// Forward declarations
 class HbLineEdit;
 class HbTranslator;
 class EapQtValidator;
 
+// External data types
+
+// Constants
+
+/*!
+   @addtogroup group_eap_fast_create_master_key_query_dialog
+   @{
+ */
+
+// Class declaration
+
 class EapFastCreateMasterKeyQueryDialog: public HbInputDialog, public HbDeviceDialogInterface
     {
     Q_OBJECT
@@ -44,17 +58,18 @@
         void createDialog( const QVariantMap &parameters );
         
         /* Device dialog parameters to be set while dialog is displayed.
-         * Not supported.
+         * Not supported. (from HbDeviceDialogInterface)
          */
         bool setDeviceDialogParameters(const QVariantMap &parameters);
         
-        /* Not supported */
+        /* Not supported. (from HbDeviceDialogInterface) */
         int deviceDialogError() const;
         
         /* Closes the device dialog */
         void closeDeviceDialog(bool byClient);
         
-        /* Returns a pointer to this dialog widget */
+        /* Returns a pointer to this dialog widget.
+           (from HbDeviceDialogInterface) */
         HbPopup *deviceDialogWidget() const;
                 
     signals:
@@ -80,29 +95,32 @@
         
         Q_DISABLE_COPY(EapFastCreateMasterKeyQueryDialog)
    
-    private:
-        /* Pointer to the line edit 1 object */
+    private: // data
+        // NOT OWNED
+        //! Pointer to the line edit 1 object 
         HbLineEdit *mEdit1;
         
-        /* Pointer to the line edit 2 object */
+        //! Pointer to the line edit 2 object
         HbLineEdit *mEdit2;
-                
-        /* Pointer to the password validator object */
+        
+        // OWNED                
+        //! Pointer to the password validator object
         QScopedPointer<EapQtValidator> mPwdValidator;
                 
-        /* Pointer to the HbTranslator */
+        //! Pointer to the HbTranslator
         QScopedPointer<HbTranslator> mTranslator;
         
-        /* Pointer to the error message HbTranslator */
+        //! Pointer to the error message HbTranslator
         QScopedPointer<HbTranslator> mErrMsgTranslator;
         
-        /* Tells whether close has already been called for the dialog */
+        //! Tells whether close has already been called for the dialog
         bool mClose;
         
-        /* Tells whether Ok Action has already been pressed */
+        //! Tells whether Ok Action has already been pressed
         bool mOkActionPressed;
     };
 
+/*! @} */
 
 #endif // __EAPFASTCREATEMASTERKEYQUERYDIALOG_H__
@@ -11,25 +11,39 @@
 * Contributors:
 *
-* Description: Fast Create Master Key Query Dialog
+* Description: EAP-FAST Create Master Key Query Dialog
 *
 */
@@ -44,17 +58,18 @@
         int deviceDialogError() const;
         
-        /* Closes the device dialog */
+        /* Closes the device dialog. (from HbDeviceDialogInterface) */
         void closeDeviceDialog(bool byClient);
         